@@ -84,7 +84,7 @@
 #define KJOBWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KJOBWIDGETS_NO_DEPRECATED
-#  define KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KJOBWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
